"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class RouteMerger {
    constructor(routes, sequence, removeRouteType) {
        this.routes = routes;
        this.sequence = sequence;
        this.removeRouteType = removeRouteType;
    }
    /**
     * Output and re-index all routes. A map of old route ID to new route ID is returned.
     */
    async write(routes) {
        const routeIndex = {};
        for (const route of routes) {
            if (!this.removeRouteType[route.route_type]) {
                const routeId = this.sequence.next();
                routeIndex[route.route_id] = routeId;
                route.route_id = routeId;
                await this.push(route);
            }
        }
        return routeIndex;
    }
    push(data) {
        const writable = this.routes.write(data);
        if (!writable) {
            return new Promise(resolve => this.routes.once("drain", resolve));
        }
    }
    /**
     * Flush all the data to the output stream
     */
    async end() {
        return new Promise(resolve => this.routes.end(resolve));
    }
}
exports.RouteMerger = RouteMerger;
